    robotframework_init, is a scaffolding which can help you install most robot framework need,
    and it can create a empty project。  
    robotframework_init 是一个脚手架工具，通过它可以帮你安装大部分常用的 robot framework需要的包，
    且会生成一个统一文档结构。  

`Example`  
rf_init.py --project_name test_rf
